/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * MapAnnotation.cpp
 *
 *  Created on: Oct 27, 2010
 *      Author: ltwardon
 */

#include "MapAnnotation.h"

using namespace std;
using namespace xmltio;
using namespace airobots;

namespace airobots {

MapAnnotation::MapAnnotation() {

}

std::string MapAnnotation::getBaseTag() {
	return "ANNOTATION";
}

std::string MapAnnotation::getTemplate() {
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate()
			+ "</" + getBaseTag() + ">";
}

void MapAnnotation::addArea(MapArea area) {
	areas.push_back(area);
}

void MapAnnotation::setAreas(list<MapArea> areas) {
	this->areas = areas;
}

list<MapArea> MapAnnotation::getAreas() const {
	return areas;
}

list<MapArea> MapAnnotation::getAreasByType(MapArea::MapAreaType areaType) const {

	list<MapArea> areasByType;
	list<MapArea>::const_iterator i;
	for (i=areas.begin(); i!=areas.end(); ++i) {
		if(i->getType() == areaType)
			areasByType.push_back(*i);
	}
	return areas;

}

list<MapArea> MapAnnotation::getAreasByName(std::string name) const {

	list<MapArea> areasByName;
	list<MapArea>::const_iterator i;
	for (i=areas.begin(); i!=areas.end(); ++i) {
		if(i->getArenaName() == name)
			areasByName.push_back(*i);
	}
	return areas;

}

void MapAnnotation::sanitizeLocation(xmltio::Location &loc) const {

}

void MapAnnotation::fillInto(xmltio::Location &loc) const{

	Type::fillInto(loc);

	// Area
	for(list<MapArea>::const_iterator it_area = areas.begin(); it_area!=areas.end(); ++it_area) {

		Location loc_area("<AREA type=\"\" name=\"\" />", "/AREA");
		loc_area[XPath("@type")] = MapArea::mapAreaTypeValue[it_area->getType()];
		loc_area[XPath("@name")] = it_area->getArenaName();

		// Region
		list<MapRegion> regionlist = it_area->getRegions();
		for(list<MapRegion>::const_iterator it_region = regionlist.begin(); it_region!=regionlist.end(); ++it_region) {
			Location loc_region("<REGION type=\"\" label=\"\" group=\"\" high=\"\" />", "/REGION");
			loc_region[XPath("@type")] = it_region->getType();
			loc_region[XPath("@label")] = it_region->getLabel();
			loc_region[XPath("@group")] = it_region->getGroup();
			loc_region[XPath("@high")] = it_region->getHeight();

			if(it_region->isViewPointSet()) {
				// VIEW_POINT
				Location loc_view_point("<VIEW_POINT x=\"\" y=\"\" yaw=\"\" />", "/VIEW_POINT");
				loc_view_point[XPath("@x")] = it_region->getViewPoint().getX();
				loc_view_point[XPath("@y")] = it_region->getViewPoint().getY();
				loc_view_point[XPath("@yaw")] = it_region->getViewPoint().getTheta();
				loc_region.add(loc_view_point);
			}

			// COORD
			list<MapPoint>pointlist = it_region->getPoints();
			for(list<MapPoint>::const_iterator it_point = pointlist.begin(); it_point!=pointlist.end(); ++it_point) {
				Location loc_coord("<COORD x=\"\" y=\"\" kind=\"\" unit=\"\" ref=\"\" />", "/COORD");
				loc_coord[XPath("@x")] = it_point->getX();
				loc_coord[XPath("@y")] = it_point->getY();
				loc_coord[XPath("@kind")] = MapPoint::kindValue[it_point->getKind()];
				loc_coord[XPath("@unit")] = MapPoint::unitValue[it_point->getUnit()];
				loc_coord[XPath("@ref")] = it_point->getRef();
				loc_region.add(loc_coord);
			}

			loc_area.add(loc_region);

		}

		loc.add(loc_area);

	}

}

void MapAnnotation::fromLocation(const xmltio::Location &loc, MapAnnotation &type) {

	Type::fromLocation(loc, type);

	// Area
	for(XPathIterator i = XPath("AREA").evaluate(loc); i; ++i) {
		Location loc_area(*i);
		MapArea::MapAreaType areaType;
		if(extract<string>(loc_area[XPath("@type")]).get() == "NOGO") areaType = MapArea::NOGO;
		else if(extract<string>(loc_area[XPath("@type")]).get() == "ROOM") areaType = MapArea::ROOM;
		else if(extract<string>(loc_area[XPath("@type")]).get() == "INTEREST") areaType = MapArea::INTEREST;
		else if(extract<string>(loc_area[XPath("@type")]).get() == "PERSON") areaType = MapArea::PERSON;
		else if(extract<string>(loc_area[XPath("@type")]).get() == "DISTURB") areaType = MapArea::DISTURB;
		else if(extract<string>(loc_area[XPath("@type")]).get() == "OBJECTS") areaType = MapArea::OBJECTS;
		else if(extract<string>(loc_area[XPath("@type")]).get() == "NO_TYP") areaType = MapArea::NO_TYP;
		list<MapRegion> regions;
		MapArea area(areaType,
				extract<string>(loc_area[XPath("@name")]),
				regions);

		// Region
		for(XPathIterator j = XPath("REGION").evaluate(loc_area); j; ++j) {
			Location loc_region(*j);
			MapRegion region("");
			region.setType(extract<string>(loc_region[XPath("@type")]));
			region.setLabel(extract<string>(loc_region[XPath("@label")]));
			region.setGroup(extract<string>(loc_region[XPath("@group")]));
			region.setHeight(extract<double>(loc_region[XPath("@high")]));

			// VIEW_POINT
			LocationPtr loc_view_point_ptr = find(Location(loc_region), "VIEW_POINT");
			if(loc_view_point_ptr) {
				NavigationGoalData viewPoint(type.getGenerator(),
						extract<double>((*loc_view_point_ptr)[XPath("@x")]),
						extract<double>((*loc_view_point_ptr)[XPath("@y")]),
						extract<double>((*loc_view_point_ptr)[XPath("@yaw")]),
						NavigationGoalData::GLOBAL);
				region.setViewPoint(viewPoint);
			}

			// COORD
			for(XPathIterator k = XPath("COORD").evaluate(loc_region); k; ++k) {
				Location loc_coord(*k);
				MapPoint::Kind kind;
				if(extract<string>(loc_coord[XPath("@kind")]).get() == "WORLD") kind = MapPoint::WORLD;
				else if(extract<string>(loc_coord[XPath("@kind")]).get() == "RELATIVE") kind = MapPoint::RELATIVE;
				MapPoint::Unit unit;
				if(extract<string>(loc_coord[XPath("@unit")]).get() == "M") unit = MapPoint::M;
				else if(extract<string>(loc_coord[XPath("@unit")]).get() == "CM") unit = MapPoint::CM;
				else if(extract<string>(loc_coord[XPath("@unit")]).get() == "MM") unit = MapPoint::MM;
				else if(extract<string>(loc_coord[XPath("@unit")]).get() == "NM") unit = MapPoint::NM;
				double x = extract<double>(loc_coord[XPath("@x")]);
				double y = extract<double>(loc_coord[XPath("@y")]);
				MapPoint point(x,
						y,
						kind,
						unit,
						extract<string>(loc_coord[XPath("@ref")]));
				region.addPoint(point);
			}

			area.addRegion(region);

		}

		type.areas.push_back(area);

	}

}

}
