/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * MapPoint.h
 *
 *  Created on: Oct 13, 2010
 *      Author: ltwardon
 */

#ifndef MAPPOINT_H_
#define MAPPOINT_H_

#include <string>

namespace airobots {

class MapPoint {

public:

	enum Unit{
		M,
		CM,
		MM,
		NM
	};

	static const std::string unitValue[];

	enum Kind{
		WORLD,
		RELATIVE
	};

	static const std::string kindValue[];

	MapPoint();
	MapPoint(double x, double y);
	MapPoint(double x, double y, Kind kind, Unit unit, std::string ref);
	virtual ~MapPoint();

	double getX() const;
	void setX(double x);
	double getY() const;
	void setY(double y);
	Kind getKind() const;
	void setKind(Kind kind);
	Unit getUnit() const;
	void setUnit(Unit unit);
	std::string getRef() const;
	void setRef(std::string ref);

private:

	double x;
	double y;
	Kind kind;
	Unit unit;
	std::string ref;

};

}

#endif /* MAPPOINT_H_ */
