/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#include "StateChangeRequest.h"

using namespace std;
using namespace airobots;
using namespace xmltio;

const std::string StateChangeRequest::STATE_ELEMENT = "STATE";

StateChangeRequest::StateChangeRequest() {
	std::string newStateName = "unknown";
}



StateChangeRequest::~StateChangeRequest() {
}



const std::string StateChangeRequest::getNewStateName() const {
	return newStateName;
}



void StateChangeRequest::setNewStateName(std::string name) {
	newStateName = name;
}



std::string StateChangeRequest::getBaseTag() {
	return "STATECHANGE";
}



std::string StateChangeRequest::getTemplate() {
	return "<" + getBaseTag() + ">" + "<GENERATOR/>"
		+ Timestamp::getTemplate() + "<" + STATE_ELEMENT + "/>" + "</" + getBaseTag() + ">";
}



void StateChangeRequest::fromLocation(const xmltio::Location & loc, StateChangeRequest & scr) {
	Type::fromLocation(loc, scr);
	string stateString = extract<string>(loc[XPath(STATE_ELEMENT)]);
	scr.setNewStateName(stateString);
}



void StateChangeRequest::sanitizeLocation(xmltio::Location & loc) const {

}



void StateChangeRequest::fillInto(xmltio::Location & loc) const {
	Type::fillInto(loc);
	loc[XPath(STATE_ELEMENT)] = getNewStateName();
}


