/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * RegionDataTest.cpp
 *
 *  Created on: Jun 23, 2010
 *      Author: lziegler
 */

#include <boost/test/unit_test.hpp>
#include <boost/test/floating_point_comparison.hpp>

#include <iostream>

#include <sys/time.h>
#include <time.h>

#include "btl/RegionData.h"
#include "utils.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

static const double TOLERANCE = 0.0001;

BOOST_AUTO_TEST_SUITE(RegionDataTest)

BOOST_AUTO_TEST_CASE(testSelfCompatibility) {

	try {

		vector<pair<double,double> > polygon;
		polygon.push_back(pair<double,double>(0,0));
		polygon.push_back(pair<double,double>(1,1));
		polygon.push_back(pair<double,double>(2,2));

		RegionData original;
		original.setScope(RegionData::LOCAL);
		original.setPolygon(polygon, MILLIMETER);
		original.setGenerator("generator123");
		original.setTimestamp(Timestamp());

		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, original.getPolygon(CENTIMETER)[2].first * 10, TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, original.getPolygon(METER)[2].first * 1000, TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, original.getPolygon(MILLIMETER)[2].first, TOLERANCE);
		original.setPolygon(polygon, MILLIMETER);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, 2.0, TOLERANCE);
		original.setPolygon(polygon, METER);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, 2000.0, TOLERANCE);
		original.setPolygon(polygon, CENTIMETER);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, 20.0, TOLERANCE);
		original.setPolygon(polygon, MILLIMETER);

		Location originalLoc(RegionData::getTemplate(), RegionData::getBaseTag());

		originalLoc = original;

		cout << originalLoc.getDocumentText(true) << endl;

		RegionData parsed = extract<RegionData>(originalLoc);

		BOOST_REQUIRE_EQUAL(original.getGenerator(), parsed.getGenerator());
		BOOST_REQUIRE_EQUAL(original.getTimestamp(), parsed.getTimestamp());
		BOOST_REQUIRE_EQUAL(original.getScope(), parsed.getScope());
		BOOST_REQUIRE_EQUAL(original.getPolygon(MILLIMETER).size(), parsed.getPolygon(MILLIMETER).size());
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[0].first, parsed.getPolygon(MILLIMETER)[0].first, TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[1].first, parsed.getPolygon(MILLIMETER)[1].first, TOLERANCE);
		BOOST_REQUIRE_CLOSE(original.getPolygon(MILLIMETER)[2].first, parsed.getPolygon(MILLIMETER)[2].first, TOLERANCE);

		BOOST_REQUIRE(original == parsed);

	} catch (std::exception &e) {
		BOOST_FAIL(string("Caught exception: ") + e.what());
	}

}

BOOST_AUTO_TEST_CASE(testFileCompatibility) {

	Location fileContents(readFile("RegionData.xml"), RegionData::getBaseTag());
	RegionData parsed = extract<RegionData>(fileContents);

	BOOST_REQUIRE_EQUAL("RegionDetector", parsed.getGenerator());
	BOOST_REQUIRE_EQUAL(253543797, parsed.getTimestamp().getInserted());
	BOOST_REQUIRE_EQUAL(253543712, parsed.getTimestamp().getUpdated());
	BOOST_REQUIRE_EQUAL(RegionData::LOCAL, parsed.getScope());
	BOOST_REQUIRE_EQUAL(3.0, parsed.getPolygon(MILLIMETER).size());
	BOOST_REQUIRE_CLOSE(0.0, parsed.getPolygon(MILLIMETER)[0].first, TOLERANCE);
	BOOST_REQUIRE_CLOSE(1.0, parsed.getPolygon(MILLIMETER)[1].first, TOLERANCE);
	BOOST_REQUIRE_CLOSE(2.0, parsed.getPolygon(MILLIMETER)[2].first, TOLERANCE);

}

BOOST_AUTO_TEST_SUITE_END()
