/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data;

import nu.xom.Element;

/**
 * This is only for convenience because bonsai does not support the {@link List}
 * type so far.
 * 
 * @author lziegler
 */
public class PointCloudGraspingList extends List<PointCloudGrasping> {

	
	/**
	 * Constructor.
	 */
	public PointCloudGraspingList() {
		super(PointCloudGrasping.class);
		setLegacyParsing(true);
	}

	/**
	 * Returns the tag name of the the root tag this type is usually used with
	 * in xml.
	 * 
	 * @return tag name
	 */
	public static String getBaseTag() {
		return List.getBaseTag(PointCloudGrasping.class);
	}
	
	/**
	 * Parses the contents of the given nu.xom.Element into the type instance.
	 * Therefore element must already be parsed into the base tag of the list
	 * type.
	 * 
	 * @param element
	 *            element to get the contents of this type from
	 * @param type
	 *            type to fill with the contents
	 */
	public static void fromElement(Element element,
			PointCloudGraspingList type) {
		List.fromElement(element, type);
	}
}
