/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.asu;

/**
 * Contains all states of utterances.
 * 
 * @author malinke
 */
public enum ProcessingStatus {

	/**
	 * Understood lesser than 25% of the words.
	 */
	nonunderstanding,
	/**
	 * Understood up to 50% of the words.
	 */
	partialunderstanding,
	/**
	 * Understood more than 50% of the words.
	 */
	fullunderstanding;

	private static final float UNDERSTANDING_LIMIT = 0.25f;

	private static final float FULLUNDERSTANDING_LIMIT = 0.5f;

	/**
	 * Returns the fitting state of understanding / rating.
	 * 
	 * @param rating
	 *            of an linked hypothesis
	 * @return understanding state of utterance
	 */
	public static ProcessingStatus forRating(final float rating) {
		if (rating < UNDERSTANDING_LIMIT) {
			return nonunderstanding;
		}
		if (rating <= FULLUNDERSTANDING_LIMIT) {
			return partialunderstanding;
		}
		assert rating > FULLUNDERSTANDING_LIMIT : "state eval error";
		return fullunderstanding;

	}

}
