/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data;

import static org.junit.Assert.*;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.common.MicroTimestamp;
import de.unibi.airobots.btl.common.Timestamp;

/**
 * Test cases for {@link Type}.
 * 
 * @author jwienke
 */
public class SpeedDataTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {

		SpeedData original = new SpeedData();
		final long timestamp = System.currentTimeMillis();
		original.setTimestamp(timestamp);
		original.setGenerator("test");
		original.setSpeedRotation(-0.45);
		original.setSpeedTranslation(12.45);

		Document doc = new Document(new Element(SpeedData.getBaseTag()));
		original.fillInto(doc.getRootElement());
		logger.info(doc.toXML());

		SpeedData parsed = new SpeedData();
		SpeedData.fromElement(doc.getRootElement(), parsed);

		assertEquals(original.getGenerator(), parsed.getGenerator());
		assertEquals(original.getTimestamp(), parsed.getTimestamp());
		assertEquals(original.getSpeedRotation(), parsed.getSpeedRotation(),
				0.0001);
		assertEquals(original.getSpeedTranslation(), parsed
				.getSpeedTranslation(), 0.0001);

	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils.makeTestFileName("Speed.xml"));

		SpeedData parsed = new SpeedData();
		SpeedData.fromElement(doc.getRootElement(), parsed);
		assertEquals(doc.getRootElement().getLocalName(), SpeedData
				.getBaseTag());

		assertEquals("test", parsed.getGenerator());
		assertEquals(new Timestamp(12345, 67890), parsed.getTimestamp());
		assertEquals(new MicroTimestamp(123213412, 335435), parsed
				.getReadTime());
		assertEquals(-0.34, parsed.getSpeedRotation(), 0.0001);
		assertEquals(2.45, parsed.getSpeedTranslation(), 0.0001);

	}
	
	@Test
	public void genericFromDocument() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils.makeTestFileName("Speed.xml"));

		SpeedData parsed = SpeedData.fromDocument(doc, SpeedData.class);

		assertEquals("test", parsed.getGenerator());
		assertEquals(new Timestamp(12345, 67890), parsed.getTimestamp());
		assertEquals(new MicroTimestamp(123213412, 335435), parsed
				.getReadTime());
		assertEquals(-0.34, parsed.getSpeedRotation(), 0.0001);
		assertEquals(2.45, parsed.getSpeedTranslation(), 0.0001);

	}

}
